<?php

namespace App\Http\Controllers\Auth;

use App\Models\ClientAuthCodes;
use App\User;
use App\Http\Controllers\Controller;
use Carbon\Carbon;
use Illuminate\Auth\Events\Registered;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Validator;
use Illuminate\Foundation\Auth\RegistersUsers;

class RegisterController extends Controller
{
    /*
    |--------------------------------------------------------------------------
    | Register Controller
    |--------------------------------------------------------------------------
    |
    | This controller handles the registration of new users as well as their
    | validation and creation. By default this controller uses a trait to
    | provide this functionality without requiring any additional code.
    |
    */

    use RegistersUsers;

    /**
     * Where to redirect users after registration.
     *
     * @var string
     */
    protected $redirectTo = '/packages';

    /**
     * Create a new controller instance.
     *
     * @return void
     */
    public function __construct()
    {
        $this->middleware('guest');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param array $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => ['required', 'string', 'max:255'],
            'surname' => ['required', 'string', 'max:255'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => ['required', 'string', 'min:8', 'confirmed'],
        ]);
    }

    public function register(Request $request)
    {
        $this->validator($request->all())->validate();

        event(new Registered($user = $this->create($request->all())));

//        $this->guard()->login($user);

        return $this->registered($request, $user)
            ?: redirect($this->redirectPath());
    }

    /**
     * Create a new user instance after a valid registration.
     *
     * @param array $data
     * @return \App\User
     */
    protected function create(array $data)
    {

        $user = User::create([
            'name' => $data['name'],
            'surname' => $data['surname'],
            'email' => $data['email'],
            'password' => Hash::make($data['password']),
            'uni_code' => $this->generateUniqNumber(),
            'client_type' => 'WEB',
        ]);
        $authCode = ClientAuthCodes::create([
            'client_id' => $user->id,
            'code' => $this->generateUniqNumber(4),
            'life_time' => Carbon::now()->addMinute(10)

        ]);
//        $success['client_id'] = $customer->id; //$customer->createToken('erpTuronApp')->accessToken;
//        $success['pass_code'] = $authCode->code;
//        $success['name'] = $customer->first_name .' '.$customer->second_name;

        $to_name = $user->name . ' ' . $user->surname;
        $to_email = $user->email;
        $data = array('code' => $authCode->code);
        Mail::send('emails', $data, function ($message) use ($to_name, $to_email) {
            $message->to($to_email, $to_name)
                ->subject('Fazo Cargo | Checking customer email');
            $message->from('noreply@fazoshop.us', 'Verification code');
        });

        return $user;
    }
}
