<?php
/**
 * Created by PhpStorm.
 * User: Skalden
 * Date: 6/30/2018
 * Time: 11:10 PM
 */

namespace App\Models;

use Illuminate\Database\Eloquent\Model;
use Illuminate\Support\Facades\DB;

class Package extends Model
{
    protected $table = 'package';
    public $timestamps = false;
    protected $fillable = ['status', 'market_link', 'track_number', 'package_name', 'comment', 'delivery_cost'];

    public const STATUS_PENDING = 'pending';
    public const STATUS_INSTORE = 'instore';
    public const STATUS_ONPACKING = 'onpacking';
    public const STATUS_SENT = 'sent';
    public const STATUS_DELIVERED = 'delivered';

    public static $statuses_descr = [
        self::STATUS_PENDING => 'Ожидается',
        self::STATUS_INSTORE => 'На складе',
        self::STATUS_ONPACKING => 'На упаковке',
        self::STATUS_SENT => 'Отправлена',
        self::STATUS_DELIVERED => 'Доставлена'
    ];

    public static $statuses_colors = [
        self::STATUS_PENDING => 'danger',
        self::STATUS_INSTORE => 'warning',
        self::STATUS_ONPACKING => 'info',
        self::STATUS_SENT => 'primary',
        self::STATUS_DELIVERED => 'success'
    ];

    public function package_number()
    {
        return 'UPI01'.$this->id;
    }

    public static function user_total_packages()
    {
        return Package::where('user_id', 1)->count();
    }

    public function total_items()
    {
        return (int)PackageItems::where('package_id', $this->id)->count();
    }

    public function items_cost()
    {
        return (int)PackageItems::where('package_id', $this->id)->sum('price');
    }

    public function items_weight()
    {
        $weight = DB::table('package_items')
            ->select(DB::raw('ROUND(SUM(weight), 2) as total_weight'))
            ->where('package_id', '=', $this->id)
            ->first();
        return $weight->total_weight;
    }

    public function user()
    {
        return $this->belongsTo('App\User', 'user_id', 'id');
    }
}