@extends('layouts.app')
@section('page-title', 'Управление адресами для доставки')
@section('content')
    <div class="py-5 text-center">
        <img class="d-block mx-auto mb-4" src="{{ url('images/ship/location.png') }}" alt="" width="72" height="72">
        <h2>Добавление нового адреса</h2>
        <p class="lead">Тут вам необходимо заполнить форму с информацией об адресе в Узбекистане и прикрепить скан-копию паспорта. Эта информация может быть необходимой на таможне по прибытию посылки в Узбекистан или для доставки посылки нашими курерами к вашему дому.</p>
    </div>

    <div class="row">
        <div class="col-md-12 mb-4">

            @if($address->exists)
                <form class="needs-validation border border-success bg-white p-5" action="{{ url('/profile/address/edit/'.$address->id) }}" method="POST" enctype="multipart/form-data" novalidate>
            @else
                <form class="needs-validation border border-success bg-white p-5" action="{{ url('/profile/address/add') }}" method="POST" enctype="multipart/form-data" novalidate>
            @endif

                {{ csrf_field() }}

                <h4 class="d-flex justify-content-between align-items-center mb-3">
                    <span class="text-muted">Добавление адреса</span>
                </h4>

                <div class="row">
                    <div class="col-md-4 mb-3">
                        <label for="firstname">Фамилия получателя</label>
                        <input type="text" class="form-control" id="firstname" name="firstname" placeholder="" value="{{ array_get($_POST, 'firstname', $address->firstname) }}" required>
                        <div class="invalid-feedback">
                            Valid first name is required.
                        </div>
                    </div>
                    <div class="col-md-4 mb-3">
                        <label for="secondname">Имя получателя</label>
                        <input type="text" class="form-control" id="secondname" name="secondname" placeholder="" value="{{ array_get($_POST, 'secondname', $address->secondname) }}" required>
                        <div class="invalid-feedback">
                            Valid last name is required.
                        </div>
                    </div>
                    <div class="col-md-4 mb-3">
                        <label for="fathername">Отчество получателя</label>
                        <input type="text" class="form-control" id="fathername" name="fathername" placeholder="" value="{{ array_get($_POST, 'fathername', $address->fathername) }}" required>
                        <div class="invalid-feedback">
                            Valid last name is required.
                        </div>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-4 mb-3">
                        <label for="phone">Телефон</label>
                        <input type="text" class="form-control" id="phone" name="phone" value="{{ array_get($_POST, 'phone', $address->phone) }}">
                        <div class="invalid-feedback">
                            Пожалуйста введите телефон
                        </div>
                    </div>
                </div>

                <div class="row mt-4">
                    <div class="col-md-4 mb-3">
                        <label for="country">Страна</label>
                        <select class="form-control" id="country" name="country">
                            <option value="uzb">Узбекистан</option>
                        </select>
                    </div>

                    <div class="col-md-4 mb-3">
                        <label for="oblast">Область</label>
                        <select class="form-control" id="oblast" name="oblast">
                            @foreach(\App\Models\Address::$oblast as $key => $value)
                                <option value="{{ $key }}" {{ array_get($_POST, 'oblast', $address->oblast) == $key ? 'selected' : '' }}>{{ $value }}</option>
                            @endforeach
                        </select>
                    </div>

                    <div class="col-md-4 mb-3">
                        <label for="city">Город</label>
                        <input type="text" class="form-control" id="city" name="city" placeholder="" value="{{ array_get($_POST, 'city', $address->city) }}" required>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-4 mb-3">
                        <label for="street">Улица</label>
                        <input type="text" class="form-control" id="street" name="street" placeholder="" value="{{ array_get($_POST, 'street', $address->street) }}" required>
                    </div>

                    <div class="col-md-4 mb-3">
                        <label for="house">Дом</label>
                        <input type="text" class="form-control" id="house" name="house" placeholder="" value="{{ array_get($_POST, 'house', $address->house) }}" required>
                    </div>

                    <div class="col-md-4 mb-3">
                        <label for="apartment">Квартира</label>
                        <input type="text" class="form-control" id="apartment" name="apartment" placeholder="" value="{{ array_get($_POST, 'apartment', $address->apartment) }}" required>
                    </div>
                </div>

                <div class="row">
                    <div class="col-md-4 mb-3">
                        <label for="zip">Почтовый индекс</label>
                        <input type="text" class="form-control" id="zip" name="zip" placeholder="" value="{{ array_get($_POST, 'zip', $address->zip) }}" required>
                    </div>
                </div>

                @if($address->exists)
                    <h6 class="mt-3">Скан-копия паспорта</h6>
                    <table class="table table-striped table-hover table-sm">
                        <thead>
                        <tr>
                            <th>#</th>
                            <th>Файл</th>
                            <th class="text-right">Действия</th>
                        </tr>
                        </thead>
                        <tbody>
                        <tr>
                            <td>1</td>
                            <td><a href="{{ $address->image->url() }}">{{ $address->image->upload_name }}</a></td>
                            <td class="text-right"><a href="#" class="btn btn-danger btn-sm">-</a> </td>
                        </tr>
                        </tbody>
                    </table>
                @endif

                <span>Загрузить скан-копию</span>
                <div class="input-group mb-3 mt-2">
                    <div class="custom-file">
                        <input type="file" class="custom-file-input" id="scanFile" name="scanFile">
                        <label class="custom-file-label" for="scanFile">Выбрать файл</label>
                    </div>
                </div>

                <hr class="mb-4">
                <button class="btn btn-success btn-lg btn-block" type="submit">Сохранить</button>
            </form>
        </div>
    </div>
@endsection
